import random

from generate import IMAGES

POST_COUNT = 20


def generate():
    objects = []

    # gen post objects
    for i in range(1, POST_COUNT + 1):
        objects.append({
            "model": "post.Post",
            "fields": {
                "title": "Post %s Title" % i,
                "description": "Post %s description with some added text to \
verify truncates where needed." % i,
                "state": "published",
                "image": random.sample(IMAGES, 1)[0],
                "content": "<strong>strong</strong><i>italic</i>",
                "sites": {
                    "model": "sites.Site",
                    "fields": {
                        "name": "example.com"
                    }
                },
            },
        })

    return objects



from django.core.urlresolvers import reverse
from jmbo.models import ModelBase
from ckeditor.fields import RichTextField


class Post(ModelBase):
    content = RichTextField(
        blank=True,
        null=True,
    )

    class Meta():
        verbose_name = 'Post'
        verbose_name_plural = 'Posts'



from django.core.urlresolvers import reverse
from django.utils.translation import ugettext as _

from post.models import Post
from jmbo.generic.views import GenericObjectDetail, GenericObjectList
from jmbo.view_modifiers import DefaultViewModifier


class ObjectList(GenericObjectList):
    def get_extra_context(self, *args, **kwargs):
        return {'title': _('Posts')}

    def get_view_modifier(self, request, *args, **kwargs):
        return DefaultViewModifier(request, *args, **kwargs)

    def get_paginate_by(self, *args, **kwargs):
        return 12

    def get_queryset(self, *args, **kwargs):
        return Post.permitted.all()

object_list = ObjectList()


class ObjectDetail(GenericObjectDetail):
    def get_queryset(self, *args, **kwargs):
        return Post.permitted.all()

    def get_extra_context(self, *args, **kwargs):
        return {'title': 'Posts'}

    def get_view_modifier(self, request, *args, **kwargs):
        return DefaultViewModifier(
            request,
            base_url=reverse("object_list", args=['post', 'post']),
            ignore_defaults=True,
            *args,
            **kwargs
        )

object_detail = ObjectDetail()
